====
QuickAlgo for LPMM
====

See our github: `MaiM-with-u/MaiMBot-LPMM <https://github.com/MaiM-with-u/MaiMBot-LPMM>`_

This library is specially designed for LPMM(Long-term and Persistent Memory) and is not intended to be used in other projects. It is a lightweight library that focuses on providing high performance impl of DirectedGraph structure and PageRank algorithm.